@@ -4,19 +4,22 @@ import json
 import scenario_testing_tools
 import warnings
 
+"""
+Python version: 3.7
+Created by: Tim Stahl
+Created on: 27.04.2019
+
+Sample script extracting scenario data for a given time instance 't_in'. If the given time step is not present in the
+data file, linear interpolation is used to generate the desired instance between the neighboring time instances.
+"""
+
 
 def get_scene_timesample(file_path: str,
-                         t_in: float):
+                         t_in: float) -> tuple:
     """
-    Python version: 3.5
-    Created by: Tim Stahl
-    Created on: 27.04.2019
+    Method extracting scenario data for a given time instance. If the given time step is not present in the data file,
+    linear interpolation is used to generate the desired instance between the neighboring time instances.
 
-    Documentation:  Sample script extracting scenario data for a given time instance. If the given time step is not
-                    present in the data file, linear interpolation is used to generate the desired instance between the
-                    neighboring time instances.
-
-    Inputs:
     :param file_path:       string holding the path to the scene data file
     :param t_in:            two options:
                             * float number holding the time-stamp to be extracted [linear interp. between neighb. pts]
@@ -145,9 +148,9 @@ def get_scene_timesample(file_path: str,
 def interp_1d(x: float,
               xp: np.ndarray,
               fp_array: np.ndarray,
-              idx_col_heading: list = None):
+              idx_col_heading: list = None) -> np.ndarray:
     """
-    extends the functionality of numpy's 'interp' to an array like structure
+    Extends the functionality of numpy's 'interp' to an array like structure
 
     :param x:                desired index for new value
     :param xp:               existing series of indexes
@@ -170,7 +173,7 @@ def interp_1d(x: float,
 # -- main --------------------------------------------------------------------------------------------------------------
 if __name__ == "__main__":
     scenario_path = (os.path.dirname(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
-                     + "/sample_scenarios/n_vehicle/modena_overtake_tight.scn")
+                     + "/sample_files/scenario_n_vehicle/modena_overtake_tight.scn")
     z = get_scene_timesample(file_path=scenario_path,
                              t_in=4.0)
     print(z)
